@@ -71,6 +71,8 @@ Q_SIGNALS:
 
     void genresAdded(const ModelDataLoader::ListGenreDataType &newData);
 
+    void genreRemoved(qulonglong removedDatabaseId);
+
     void artistsAdded(const ModelDataLoader::ListArtistDataType &newData);
 
     void artistRemoved(qulonglong removedDatabaseId);
@@ -81,7 +83,7 @@ Q_SIGNALS:
 
     void albumModified(const ModelDataLoader::AlbumDataType &modifiedAlbum);
 
-    void saveRadioModified(const ModelDataLoader::TrackDataType &trackDataType);
+    void saveTrackModified(const ModelDataLoader::ListTrackDataType &trackDataType, const QHash<QString, QUrl> &covers);
 
     void removeRadio(qulonglong radioId);
 
@@ -118,6 +120,8 @@ public Q_SLOTS:
 
     void updateSingleFileMetaData(const QUrl &url, DataTypes::ColumnsRoles role, const QVariant &data);
 
+    void trackHasBeenModified(ModelDataLoader::ListTrackDataType trackDataType, const QHash<QString, QUrl> &covers);
+
 private Q_SLOTS:
 
     void databaseTracksAdded(const ModelDataLoader::ListTrackDataType &newData);
